@@ -1,55 +1,67 @@
 from .alation import Alation
 from .models import (
     AccessToken,
-    BusinessPolicyPostItem,
+    DataDictionaryAsyncTask,
+    DataDictionaryAsyncTaskDetails,
+    DataDictionaryAsyncTaskLink,
     BusinessPolicy,
-    BusinessPolicyPutItem,
     BusinessPolicyGroupIds,
-    BusinessPolicyStewardsField,
     BusinessPolicyParams,
+    BusinessPolicyPostItem,
+    BusinessPolicyStewardsField,
+    BusinessPolicyPutItem,
     Column,
     ColumnIndex,
     ColumnItem,
-    ColumnPatchItem,
     ColumnParams,
+    ColumnPatchItem,
     Connector,
     CustomField,
+    CustomFieldDictValue,
+    CustomFieldDictValueItem,
     CustomFieldItem,
     CustomFieldParams,
+    CustomFieldStringValue,
+    CustomFieldStringValueItem,
     CustomFieldValue,
     CustomFieldValueItem,
     CustomFieldValueParams,
-    CustomFieldDictValue,
-    CustomFieldDictValueItem,
-    CustomFieldStringValue,
-    CustomFieldStringValueItem,
     CustomTemplate,
     CustomTemplateParams,
+    Dataflow,
+    DataflowParams,
+    DataflowPayload,
+    DataflowPatchItem,
+    DataflowPathObject,
+    DataDictionaryResource,
+    DataDictionaryTaskDetails,
+    DataDictionaryTaskError,
+    DataDictionaryTaskErrorDetailItems,
+    DataDictionaryTaskErrorDetails,
+    DataDictionaryTaskErrorRange,
+    DataDictionaryTaskErrorRangeEndpoint,
+    DataDictionaryTaskProgress,
+    DataDictionaryTaskRecords,
+    DataDictionaryTaskResult,
     DataQualityField,
     DataQualityFieldItem,
     DataQualityFieldParams,
     DataQualityValue,
     DataQualityValueItem,
     DataQualityValueParams,
+    Document,
     DocumentHubFolder,
     DocumentHubFolderParams,
     DocumentHubFolderPostItem,
     DocumentHubFolderPutItem,
-    OCFDatasource,
-    OCFDatasourcePutItem,
-    OCFDatasourcePostItem,
-    OCFDatasourceParams,
-    NativeDatasource,
-    NativeDatasourceParams,
-    Document,
+    DocumentParams,
     DocumentPostItem,
     DocumentPutItem,
-    DocumentParams,
     Domain,
-    DomainParams,
+    DomainMembership,
     DomainMembershipRule,
     DomainMembershipRuleRequest,
-    DomainMembership,
+    DomainParams,
     GlossaryTerm,
     GlossaryTermItem,
     GlossaryTermParams,
@@ -66,12 +78,6 @@ from .models import (
     JobDetailsDataQualityResultCreatedObjectAttribution,
     JobDetailsDocumentDelete,
     JobDetailsDocumentDeleteResult,
-    JobDetailsDocumentPost,
-    JobDetailsDocumentPostResult,
-    JobDetailsDocumentPostResultDetails,
-    JobDetailsDocumentPut,
-    JobDetailsDocumentPutResult,
-    JobDetailsDocumentPutResultDetails,
     JobDetailsDocumentHubFolderDelete,
     JobDetailsDocumentHubFolderPost,
     JobDetailsDocumentHubFolderPostResult,
@@ -79,6 +85,12 @@ from .models import (
     JobDetailsDocumentHubFolderPut,
     JobDetailsDocumentHubFolderPutResult,
     JobDetailsDocumentHubFolderPutResultUpdatedFolder,
+    JobDetailsDocumentPost,
+    JobDetailsDocumentPostResult,
+    JobDetailsDocumentPostResultDetails,
+    JobDetailsDocumentPut,
+    JobDetailsDocumentPutResult,
+    JobDetailsDocumentPutResultDetails,
     JobDetailsRdbms,
     JobDetailsRdbmsResult,
     JobDetailsRdbmsResultMapping,
@@ -86,36 +98,49 @@ from .models import (
     JobDetailsTermDeleteResult,
     JobDetailsVirtualDatasourcePost,
     JobDetailsVirtualDatasourcePostResult,
+    NativeDatasource,
+    NativeDatasourceParams,
+    OCFDatasource,
+    OCFDatasourceParams,
+    OCFDatasourcePostItem,
+    OCFDatasourcePutItem,
     Otype,
     PolicyGroup,
     PolicyGroupParams,
+    Query,
+    QueryAuthor,
+    QueryItem,
+    QueryDatasource,
+    QueryDomain,
+    QueryTag,
     RefreshToken,
     Schema,
     SchemaItem,
-    SchemaPatchItem,
     SchemaParams,
+    SchemaPatchItem,
     Table,
     TableItem,
-    TablePatchItem,
     TableParams,
+    TablePatchItem,
     TrustCheckFlag,
     TrustCheckFlagItem,
-    TrustCheckFlagSubject,
     TrustCheckFlagParams,
+    TrustCheckFlagSubject,
+    DataDictionaryItem,
     User,
     UserParams,
-    VirtualFileSystem,
-    VirtualFileSystemItem,
     VirtualDataSource,
+    VirtualDataSourceColumn,
+    VirtualDataSourceIndex,
     VirtualDataSourceItem,
     VirtualDataSourceParams,
     VirtualDataSourceSchema,
     VirtualDataSourceTable,
     VirtualDataSourceView,
-    VirtualDataSourceColumn,
-    VirtualDataSourceIndex,
+    VirtualFileSystem,
+    VirtualFileSystemItem,
     VisualConfig,
-    VisualConfigItem,
     VisualConfigComponent,
-    VisualGroupedComponent
-)
\ No newline at end of file
+    VisualConfigItem,
+    VisualGroupedComponent,
+)
