@@ -11,6 +11,8 @@ from .methods import (
     AlationConnector,
     AlationCustomField,
     AlationCustomTemplate,
+    AlationDataDictionary,
+    AlationDataflow,
     AlationDataQuality,
     AlationDatasource,
     AlationDocument,
@@ -20,6 +22,7 @@ from .methods import (
     AlationGroup,
     AlationOtype,
     AlationPolicyGroup,
+    AlationQuery,
     AlationRDBMS,
     AlationTrustChecks,
     AlationUser,
@@ -95,9 +98,15 @@ class Alation(object):
         self.custom_template = AlationCustomTemplate(
             access_token=self.access_token, session=session, host=host
         )
+        self.dataflow = AlationDataflow(
+            access_token=self.access_token, session=session, host=host
+        )
         self.data_quality = AlationDataQuality(
             access_token=self.access_token, session=session, host=host
         )
+        self.data_dictionary = AlationDataDictionary(
+            access_token=self.access_token, session=session, host=host
+        )
         self.datasource = AlationDatasource(
             access_token=self.access_token, session=session, host=host
         )
@@ -134,6 +143,9 @@ class Alation(object):
         self.policy_group = AlationPolicyGroup(
             access_token=self.access_token, session=session, host=host
         )
+        self.query = AlationQuery(
+            access_token=self.access_token, session=session, host=host
+        )
         self.virtual_filesystem = AlationVirtualFileSystem(
             access_token=self.access_token, session=session, host=host
         )
