@@ -3,7 +3,9 @@ from .business_policy_model import *
 from .connector_model import *
 from .custom_field_model import *
 from .custom_template_model import *
+from .data_dictionary_model import *
 from .data_quality_model import *
+from .dataflow_model import *
 from .document_hub_folder_model import *
 from .datasource_model import *
 from .document_model import *
@@ -12,6 +14,7 @@ from .glossary_term_model import *
 from .group_model import *
 from .job_model import *
 from .otype_model import *
+from .query_model import *
 from .rdbms_model import *
 from .trust_check_model import *
 from .user_model import *
